@@ -24,7 +24,14 @@ if _cwd == 'zprocess' and _path not in sys.path:
 import ipaddress
 import zprocess
 from zprocess.security import SecureContext
-from zprocess.utils import gethostbyname, Interruptor, Interrupted, TimeoutError
+from zprocess.utils import (
+    gethostbyname,
+    Interruptor,
+    Interrupted,
+    TimeoutError,
+    get_venv_executable_and_env,
+    _get_fileno
+)
 from zprocess.remote import (
     RemoteProcessClient,
     RemoteOutputReceiver,
@@ -785,7 +792,7 @@ class OutputInterceptor(object):
                 raise RuntimeError(msg)
             self.streams_connected[self.streamname] = self
             stream = getattr(sys, self.streamname)
-            if stream is not None and stream.fileno() > 0:
+            if stream is not None and _get_fileno(stream) > 0:
                 self.stream_fd = stream.fileno()
             else:
                 # On Windows with pythonw, sys.stdout and sys.stderr are None or
@@ -1386,9 +1393,9 @@ class ProcessTree(object):
             extra_env = {k.encode(): v.encode() for k, v in extra_env.items()}
 
         if remote_process_client is None:
-            env = os.environ.copy()
+            executable, env = get_venv_executable_and_env(os.environ.copy())
             env.update(extra_env)
-            child = subprocess.Popen([sys.executable] + cmd, env=env)
+            child = subprocess.Popen([executable] + cmd, env=env)
         else:
             # The remote server will prefix the path to its own Python interpreter.
             # Also, it will pass to Popen an env consisting of its own env updated with
